# rcos_match

This matching interface is designed to be used as part of [ElephantBook](https://github.com/kulits/ElephantBook) and is intended for rangers to use to manually re-identify elephants. The interface is efficient, intuitive, and easy-to-use. Some features of the matching interface include displaying ranked matches, visualizing differences between individuals by highlighting SEEK scores, and comparing multiple images side-by-side as well as zooming into images to look closely at specific features.

The matching interface was designed and created by students in the Rensselaer Center for Open Source.
